﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics;
using System.Windows.Threading;
using System.Threading;
using System.ComponentModel;
using Infragistics.Controls.Charts;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    { 
        private GroupBy _group_by;
        private ObservableCollection<ChartData> _data;
        private BrushCollection _brushes;
        private int _count = 15; 


        public MainWindow()
        {
            InitializeComponent();

            _data = ChartData.GenerateData(_count);
            _group_by = new GroupBy();
            _group_by.ItemsSource = _data;
            _group_by.GroupMemberPath = "BarName";
            _group_by.ValueMemberPath = "Value1";
            _group_by.KeyMemberPath = "Index";
             
            this.DataContext = this; 

        }

        public GroupBy MyData
        {
            get { return _group_by; }
        } 

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            // disable auto generate series before adding data item
            var series = xamDataChart1.Series.OfType<StackedBarSeries>().First();
            series.AutoGenerateSeries = false;
            // add/update data item of GroupBy object

            var next = ChartData.NextData(_count);
            ++_count;
            _data.Add(next);

            // enable auto generate series after adding data item
            series.AutoGenerateSeries = true; 
 
        }  
    }
    




    public class ChartData
    {
        public string BarName { get; set; }
        public int Index { get; set; }
        public double Value1 { get; set; }
        public Brush Color { get; set; }

        private static List<Brush> _colors = null;

        public static ChartData NextData(int cnt)
        {
            Random r = new Random();

            ChartData data = new ChartData
            {
                BarName = "Bar2",
                Index = cnt,
                Value1 = r.Next(20, 40),
                Color = (cnt % 2 == 0) ? new SolidColorBrush(Colors.Blue) : new SolidColorBrush(Colors.Aqua)
            };

            return data;
        }

        public static ObservableCollection<ChartData> GenerateData(int count)
        {

            if (_colors == null)
            {
                _colors = new List<Brush>();
                _colors.Add(new SolidColorBrush(Colors.Yellow));
                _colors.Add(new SolidColorBrush(Colors.Black));
                _colors.Add(new SolidColorBrush(Colors.Red));
                _colors.Add(new SolidColorBrush(Colors.Green));
                _colors.Add(new SolidColorBrush(Colors.PeachPuff));
            }

            ObservableCollection<ChartData> data = new ObservableCollection<ChartData>();

            Random r = new Random();

            ChartData data0 = new ChartData
            {
                BarName = "Bar1",
                Index = 0,
                Value1 = r.Next(20, 40),
                Color = _colors[r.Next(0, 4)]
            };

            data.Add(data0);

            for (int i = 1; i < count; i++)
            {
                ChartData dat = new ChartData
                {               
                    BarName = "Bar1",
                    Index = i,
                    Value1 = r.Next(20, 40),
                    Color = _colors[r.Next(0, 4)]
                };

                if (i % 3 == 0)
                {
                    dat.BarName = "Bar2";
                }

                data.Add(dat);
            }

            return data;
        }
    }
				
}
